@@ -11,7 +11,8 @@ my @to_overload;
 
 BEGIN {
     my %to_overload = (
-        compare     => [qw{ <=> cmp <= >= < > lt le gt ge == eq != ne}],
+        sort        => [qw{ <=> cmp }],
+        compare     => [qw{ <= >= < > lt le gt ge == eq != ne}],
         math        => [qw{ + - * / ** atan2 cos sin exp log sqrt int abs }],
         string      => [qw{ qr x }],
         files       => [qw{ <> -X }],
@@ -25,11 +26,13 @@ BEGIN {
     }
 }
 
-use overload @to_overload, '""' => sub {'[unknown]'};
+use overload @to_overload, '""' => 'to_string';
+
+sub to_string { '[unknown]' }
 
 sub new {
     my $class = shift;
-    state $unknown = bless {} => __PACKAGE__;
+    state $unknown = bless {} => $class;
     return $unknown;
 }
 
@@ -40,6 +43,12 @@ sub compare {
     # this suppresses the "use of unitialized value in sort" warnings
     wantarray ? () : 0;
 }
+sub sort {
+    if    ( $_[2] )                                { return -1 }
+    elsif ( Unknown::Values::is_unknown( $_[1] ) ) { return 0 } # unnecessary?
+    else                                           { return 1 }
+}
+
 sub math { confess("Math cannot be performed on unknown values") }
 
 sub dereference {
@@ -73,6 +82,10 @@ sub nomethod {
 
 
 
+
+
+
+
 =pod
 
 =head1 NAME
@@ -81,11 +94,30 @@ Unknown::Values::Instance - Internal value object for the "Unknown::Values" dist
 
 =head1 VERSION
 
+version 0.005
+
+=head1 DESCRIPTION
+
+For Internal Use Only! See L<Unknown::Values>.
+
+=head1 NAME
+
+Unknown::Values::Instance - Internal value object for the "Unknown::Values" distribution
+
+=head1 VERSION
+
 version 0.004
 
-=head1 DESCRIPTION
+=head1 AUTHOR
 
-For Internal Use Only! See L<Unknown::Values>.
+Curtis "Ovid" Poe <ovid@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Curtis "Ovid" Poe.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =head1 AUTHOR
 
